@@ -748,8 +748,10 @@ static void
 mount_drive (DriveButton *self, GtkWidget *item)
 {
     if (self->volume) {
+        GMountOperation *mount_op = gtk_mount_operation_new (NULL);
 	g_volume_mount (self->volume, G_MOUNT_MOUNT_NONE,
-			NULL, NULL, NULL, NULL);
+			mount_op, NULL, NULL, NULL);
+        g_object_unref (mount_op);
     } else {
 	g_return_if_reached();
     }
